==> v1.10.7.zip: neorv32/rtl/file_list_soc.f <==
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_package.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_sys.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_clockgate.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_fifo.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_decompressor.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_control.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_regfile.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_shifter.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_muldiv.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_bitmanip.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_fpu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_cfu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_cond.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_crypto.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_alu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_lsu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_pmp.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_bus.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cache.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_dma.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_application_image.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_imem.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_dmem.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_bootloader_image.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_boot_rom.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_xip.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_xbus.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cfs.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_sdi.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_gpio.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_wdt.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_mtime.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_uart.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_spi.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_twi.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_pwm.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_trng.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_neoled.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_xirq.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_gptmr.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_onewire.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_slink.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_crc.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_sysinfo.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_debug_dtm.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_debug_auth.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_debug_dm.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_top.vhd

==> v1.10.9.zip: neorv32/rtl/file_list_soc.f <==
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_package.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_sys.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_clockgate.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_fifo.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_decompressor.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_control.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_regfile.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_shifter.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_muldiv.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_bitmanip.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_fpu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_cfu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_cond.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_cp_crypto.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_alu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_lsu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_pmp.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu_icc.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cpu.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_bus.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cache.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_core_complex.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_dma.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_application_image.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_imem.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_dmem.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_xip.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_xbus.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_bootloader_image.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_boot_rom.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_cfs.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_sdi.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_gpio.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_wdt.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_clint.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_uart.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_spi.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_twi.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_twd.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_pwm.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_trng.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_neoled.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_xirq.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_gptmr.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_onewire.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_slink.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_crc.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_sysinfo.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_debug_dtm.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_debug_auth.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_debug_dm.vhd
NEORV32_RTL_PATH_PLACEHOLDER/core/neorv32_top.vhd
